/*
** Module   : ExpressionInitializer.java
** Abstract : Evaluates an expression and returns its type and value.
**
** Copyright (c) 2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- -----------------------Description------------------------
** 001 GES 20130203 Created initial version.
*/

package com.goldencode.expr;

/**
 * Generates an initial value for a variable, using a contained
 * {@link Expression}.
 */
public class ExpressionInitializer
extends Initializer
{
   /** The expression used to generate an initial value. */
   private Expression expr = null;
   
   /**
    * Construct an instance.
    *
    * @param    expr
    *           The expression to be used to generate an initial value.
    */
   public ExpressionInitializer(Expression expr)
   {
      this.expr = expr;
   }
   
   /**
    * Evaluate the initializer and return back the result.
    *
    * @return   The initial value.
    */
   public Object resolve()
   {
      return expr.execute();
   }

   /**
    * Report the type of object which will be returned when {@link #resolve}
    * is called.
    *
    * @return   The value's return type.
    */
   public Class<?> getReturnType()
   {
      return expr.getReturnType();
   }
}
