/*
** Module   : SourceFileHelper.java
** Abstract : provides an API for an object that helps copy and link (from
**            statistics reports) to source code
**
** Copyright (c) 2007-2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- --JPRM-- -------------------Description--------------------
** 001 GES 20070716   @34528 Provides an API for an object that helps copy
**                           and link (from statistics reports) to source
**                           code.
** 002 GES 20130206          Moved class to the pattern package.
*/

package com.goldencode.p2j.pattern;

/**
 * Provides an API for an object that helps copy and link (from statistics
 * reports) to source code. This will be used to create a source file index
 * which has a table with 1 row per source file and a column for each
 * different form of the source file that will be provided.  Each cell will
 * have a link to the resulting copied source files.
 */
public interface SourceFileHelper
{
   /**
    * Obtain the list of source file descriptions which is suitable for use
    * as the column headings in the source file index table.
    *
    * @return   Column headings.
    */
   public String[] getHeadings();
   
   /**
    * Provide the list of copy specifications for the given source file and
    * output directory.
    *
    * @param    source
    *           Original source filename.
    * @param    outDir
    *           Root of the output directory where all copies must be made.
    *
    * @return   The list of source and target copy operations to be made.
    */
   public CopySpec[] getSpecifications(String source, String outDir);
   
   /**
    * Create a URL to link to the given source file and line number.
    *
    * @param    source
    *           Original source filename.
    * @param    outDir
    *           Root of the output directory where all copies must be made.
    * @param    line
    *           The line number to which to link.
    *
    * @return   A URL to link to the copied file.
    */
   public String getURL(String source, String outDir, String line);
}
